@@ -3,6 +3,7 @@ from chordparser.keys_editor import KeyEditor
 from chordparser.scales_editor import ScaleEditor
 from chordparser.chords_editor import ChordEditor
 from chordparser.chords_analyser import ChordAnalyser
+import os.path
 
 
 class Parser:
@@ -11,7 +12,8 @@ class Parser:
 
     The Parser can use the methods under all the various Editors and Analysers. This makes it more convenient to initialise the various musical classes and interact with them.
     """
-    sample = 'sample_sheet.cho'
+    _path = os.path.join(os.path.dirname(__file__), 'sample_sheet.cho')
+    sample = open(_path, 'r')
 
     def __init__(self):
         self.NE = NoteEditor()
